==> Paws-0.16.tar.gz: Paws-0.16/lib/Paws/SNS/GetEndpointAttributes.pm <==

package Paws::SNS::GetEndpointAttributes;
  use Moose;
  has EndpointArn => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetEndpointAttributes');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SNS::GetEndpointAttributesResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'GetEndpointAttributesResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SNS::GetEndpointAttributes - Arguments for method GetEndpointAttributes on Paws::SNS

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetEndpointAttributes on the 
Amazon Simple Notification Service service. Use the attributes of this class
as arguments to method GetEndpointAttributes.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to GetEndpointAttributes.

As an example:

  $service_obj->GetEndpointAttributes(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> EndpointArn => Str

  

EndpointArn for GetEndpointAttributes input.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetEndpointAttributes in L<Paws::SNS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.17.tar.gz: Paws-0.17/lib/Paws/SNS/GetEndpointAttributes.pm <==

package Paws::SNS::GetEndpointAttributes;
  use Moose;
  has EndpointArn => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetEndpointAttributes');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::SNS::GetEndpointAttributesResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'GetEndpointAttributesResult');
1;

### main pod documentation begin ###

=head1 NAME

Paws::SNS::GetEndpointAttributes - Arguments for method GetEndpointAttributes on Paws::SNS

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetEndpointAttributes on the 
Amazon Simple Notification Service service. Use the attributes of this class
as arguments to method GetEndpointAttributes.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetEndpointAttributes.

As an example:

  $service_obj->GetEndpointAttributes(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> EndpointArn => Str

  EndpointArn for GetEndpointAttributes input.



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetEndpointAttributes in L<Paws::SNS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
